@@ -2,13 +2,10 @@
 Test the copula
 ===============
 """
+
 # %%
 import openturns as ot
 import openturns.viewer as viewer
-from matplotlib import pylab as plt
-
-ot.Log.Show(ot.Log.NONE)
-
 
 # %%
 # Copula fitting test using Kendall plot
@@ -31,7 +28,7 @@ sample2 = dist2.getSample(N)
 sample2.setName("sample2")
 
 # %%
-# We change the parameter for the evaluation of E(Wi) thanks to the `ResourceMap` :
+# We change the parameter for the evaluation of :math:`\Expect{W_i}` thanks to the :class:`~openturns.ResourceMap` :
 ot.ResourceMap.SetAsUnsignedInteger("VisualTest-KendallPlot-MonteCarloSize", 25)
 
 # %%
@@ -107,8 +104,4 @@ view = viewer.View(myGraph)
 
 # %%
 # Display figures
-plt.show()
-
-# %%
-# Reset default settings
-ot.ResourceMap.Reload()
+viewer.View.ShowAll()
